@@ -18,6 +18,7 @@
 
 
 #include "pdblauncher.h"
+#include <interfaces/idocumentcontroller.h>
 #include "debugjob.h"
 
 #include <util/executecompositejob.h>
@@ -31,9 +32,11 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KParts/MainWindow>
-#include <KDebug>
 #include <KConfigGroup>
 
+#include <QDebug>
+#include "debuggerdebug.h"
+
 
 namespace Python {
     
@@ -64,7 +67,7 @@ QString PdbLauncher::name() const
 
 KJob* PdbLauncher::start(const QString& launchMode, KDevelop::ILaunchConfiguration* cfg)
 {
-    kDebug() << "start of debugger process requested";
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "start of debugger process requested";
     if ( launchMode == "debug" ) {
         IExecuteScriptPlugin* iface = KDevelop::ICore::self()->pluginController()
                                       ->pluginForExtension("org.kdevelop.IExecuteScriptPlugin")->extension<IExecuteScriptPlugin>();
@@ -74,20 +77,33 @@ KJob* PdbLauncher::start(const QString& launchMode, KDevelop::ILaunchConfigurati
         
         // check the interpreter
         QProcess p;
+        p.setReadChannelMode(QProcess::MergedChannels);
         p.start(interpreter, QStringList() << "--version");
         p.waitForFinished(500);
-        QByteArray version = p.readAllStandardError();
-        kDebug() << "interpreter version:" << version;
-        if ( ! version.startsWith("Python 2.") ) {
+        QByteArray version = p.readAll();
+        qCDebug(KDEV_PYTHON_DEBUGGER) << "interpreter version:" << version;
+        if ( ! version.startsWith("Python 3.") ) {
             KMessageBox::error(ICore::self()->uiController()->activeMainWindow(),
-                            i18n("Sorry, debugging is only supported for Python 2.x applications."),
+                            i18n("Sorry, debugging is only supported for Python 3.x applications."),
                             i18n("Unsupported interpreter"));
-            return 0;
+            return nullptr;
         }
-        
+
+        QUrl scriptUrl;
+        if ( iface->runCurrentFile(cfg) ) {
+            auto document = KDevelop::ICore::self()->documentController()->activeDocument();
+            if ( ! document ) {
+                qCDebug(KDEV_PYTHON_DEBUGGER) << "no current document";
+                return nullptr;
+            }
+            scriptUrl = document->url();
+        }
+        else {
+            scriptUrl = iface->script(cfg, err);
+        }
+
         DebugJob* job = new DebugJob();
-        
-        job->m_scriptUrl = iface->script(cfg, err);
+        job->m_scriptUrl = scriptUrl;
         job->m_interpreter = interpreter;
         job->m_args = iface->arguments(cfg, err);
         job->m_workingDirectory = iface->workingDirectory(cfg);
@@ -95,8 +111,8 @@ KJob* PdbLauncher::start(const QString& launchMode, KDevelop::ILaunchConfigurati
         l << job;
         return new KDevelop::ExecuteCompositeJob( KDevelop::ICore::self()->runController(), l );
     }
-    kDebug() << "unknown launch mode";
-    return 0;
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "unknown launch mode";
+    return nullptr;
 }
 
 QStringList PdbLauncher::supportedModes() const
