@@ -63,14 +63,14 @@ ReferencedTopDUContext ContextBuilder::build(const IndexedString& url, Ast* node
         }
     }
     if (updateContext) {
-        qDebug() << " ====> DUCHAIN ====>     rebuilding duchain for" << url.str() << "(was built before)";
+        qCDebug(KDEV_PYTHON_DUCHAIN) << " ====> DUCHAIN ====>     rebuilding duchain for" << url.str() << "(was built before)";
         DUChainWriteLocker lock(DUChain::lock());
         Q_ASSERT(updateContext->type() == DUContext::Global);
         updateContext->clearImportedParentContexts();
         updateContext->parsingEnvironmentFile()->clearModificationRevisions();
         updateContext->clearProblems();
     } else {
-        qDebug() << " ====> DUCHAIN ====>     building duchain for" << url.str();
+        qCDebug(KDEV_PYTHON_DUCHAIN) << " ====> DUCHAIN ====>     building duchain for" << url.str();
     }
     return ContextBuilderBase::build(url, node, updateContext);
 }
@@ -199,7 +199,7 @@ void ContextBuilder::closeAlreadyOpenedContext(DUContextPointer context)
 void ContextBuilder::activateAlreadyOpenedContext(DUContextPointer context)
 {
     Q_ASSERT(m_temporarilyClosedContexts.isEmpty());
-    Q_ASSERT(contextAlreayOpen(context));
+    Q_ASSERT(contextAlreadyOpen(context));
     DUContext* current = currentContext();
     bool reallyCompilingContexts = compilingContexts();
     setCompilingContexts(false); // TODO this is very hackish.
@@ -215,7 +215,7 @@ void ContextBuilder::activateAlreadyOpenedContext(DUContextPointer context)
     setCompilingContexts(reallyCompilingContexts);
 }
 
-bool ContextBuilder::contextAlreayOpen(DUContextPointer context)
+bool ContextBuilder::contextAlreadyOpen(DUContextPointer context)
 {
     DUContext* current = currentContext();
     while ( current ) {
@@ -426,7 +426,7 @@ RangeInRevision ContextBuilder::rangeForArgumentsContext(FunctionDefinitionAst*
 void ContextBuilder::visitFunctionArguments(FunctionDefinitionAst* node)
 {
     RangeInRevision range = rangeForArgumentsContext(node);
-    
+
     // The DUChain expects the context containing a function's arguments to be of type Function.
     // The function body will have DUContext::Other as type, as it contains only code.
     DUContext* funcctx = openContext(node->arguments, range, DUContext::Function, node->name);
@@ -435,7 +435,6 @@ void ContextBuilder::visitFunctionArguments(FunctionDefinitionAst* node)
     closeContext();
     // the parameters should be visible in the function body, so import that context there
     m_importedParentContexts.append(funcctx);
-    m_mostRecentArgumentsContext = DUContextPointer(funcctx);
 }
 
 void ContextBuilder::visitFunctionDefinition(FunctionDefinitionAst* node)
@@ -479,7 +478,6 @@ void ContextBuilder::visitFunctionBody(FunctionDefinitionAst* node)
     visitNodeList(node->body);
     
     closeContext();
-    m_mostRecentArgumentsContext = DUContextPointer(0);
 }
 
 }
