@@ -21,12 +21,13 @@
 #ifndef PYTHON_DECLARATIONBUILDER_H
 #define PYTHON_DECLARATIONBUILDER_H
 
+#include <language/duchain/builders/abstracttypebuilder.h>
 #include <language/duchain/builders/abstractdeclarationbuilder.h>
 
 #include <QList>
 
+#include "contextbuilder.h"
 #include "declarations/functiondeclaration.h"
-#include "typebuilder.h"
 #include "ast.h"
 
 namespace Python
@@ -34,7 +35,9 @@ namespace Python
 
 class CorrectionHelper;
 
-typedef KDevelop::AbstractDeclarationBuilder<Ast, Identifier, TypeBuilder> DeclarationBuilderBase;
+typedef KDevelop::AbstractTypeBuilder<Ast, Identifier, ContextBuilder> TypeBuilderBase;
+
+typedef KDevelop::AbstractDeclarationBuilder<Ast, Identifier, TypeBuilderBase> DeclarationBuilderBase;
 
 class KDEVPYTHONDUCHAIN_EXPORT DeclarationBuilder: public DeclarationBuilderBase
 {
@@ -86,6 +89,7 @@ protected:
     void visitClassDefinition(ClassDefinitionAst* node) override;
     void visitFunctionDefinition(FunctionDefinitionAst* node) override;
     void visitAssignment(AssignmentAst* node) override;
+    void visitAnnotationAssignment(AnnotationAssignmentAst* node) override;
     void visitFor(ForAst* node) override;
     void visitImport(ImportAst* node) override;
     void visitImportFrom(ImportFromAst* node) override;
@@ -110,7 +114,6 @@ protected:
         AbortIfReopenMismatch = 0x1
     };
     /// Visitor helper functions
-    template<typename T> void visitDecorators(QList<ExpressionAst*> decorators, T* addTo);
     template<typename T> T* visitVariableDeclaration(Python::Ast* node, Declaration* previous=nullptr,
                                                      AbstractType::Ptr type = AbstractType::Ptr(),
                                                      VisitVariableFlags flags=NoVisitVariableFlags);
@@ -217,7 +220,7 @@ protected:
      * @param dottedName The dotted name of the module, like "random.randint".
      * @param declarationIdentifier provides the name and range
      * @param rangeNode can be used to override the declarationIdentifier's range, if required. Defaults to 0.
-     * @param createProblem whether or not to create DUChain problems Defaults to CreateProblems.
+     * @param problemEncountered the encountered problem, if there's any
      * @return :Declaration* the declaration created, or 0 if none was found.
      **/
     Declaration* createModuleImportDeclaration(QString dottedName, QString declarationName, Python::Identifier* declarationIdentifier,
@@ -276,7 +279,7 @@ private:
     QList<DUChainBase*> m_scheduledForDeletion;
     QScopedPointer<CorrectionHelper> m_correctionHelper;
     int m_ownPriority = 0;
-    StructureType::Ptr m_currentClassType;
+    QVector<StructureType::Ptr> m_currentClassTypes;
     // missing modules, for not reporting them as unknown variables
     QVector<IndexedString> m_missingModules;
 
